"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, suite_definition_configuration: Dict = None, tags: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Device Advisor test suite.

    Args:
        suite_definition_configuration(Dict, optional): Creates a Device Advisor test suite with suite definition configuration. Defaults to None.
        tags(Dict, optional): The tags to be attached to the suite definition. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotdeviceadvisor.suite.definition.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotdeviceadvisor.suite.definition.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotdeviceadvisor",
        operation="create_suite_definition",
        op_kwargs={
            "suiteDefinitionConfiguration": suite_definition_configuration,
            "tags": tags,
        },
    )


async def delete(hub, ctx, suite_definition_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a Device Advisor test suite.

    Args:
        suite_definition_id(str): Suite definition Id of the test suite to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotdeviceadvisor.suite.definition.delete(
                ctx, suite_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotdeviceadvisor.suite.definition.delete suite_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotdeviceadvisor",
        operation="delete_suite_definition",
        op_kwargs={"suiteDefinitionId": suite_definition_id},
    )


async def get(
    hub, ctx, suite_definition_id: str, suite_definition_version: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a Device Advisor test suite.

    Args:
        suite_definition_id(str): Suite definition Id of the test suite to get.
        suite_definition_version(str, optional): Suite definition version of the test suite to get. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotdeviceadvisor.suite.definition.get(
                ctx, suite_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotdeviceadvisor.suite.definition.get suite_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotdeviceadvisor",
        operation="get_suite_definition",
        op_kwargs={
            "suiteDefinitionId": suite_definition_id,
            "suiteDefinitionVersion": suite_definition_version,
        },
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the Device Advisor test suites you have created.

    Args:
        max_results(int, optional): The maximum number of results to return at once. Defaults to None.
        next_token(str, optional): A token used to get the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotdeviceadvisor.suite.definition.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotdeviceadvisor.suite.definition.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotdeviceadvisor",
        operation="list_suite_definitions",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )


async def update(
    hub, ctx, suite_definition_id: str, suite_definition_configuration: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a Device Advisor test suite.

    Args:
        suite_definition_id(str): Suite definition Id of the test suite to be updated.
        suite_definition_configuration(Dict, optional): Updates a Device Advisor test suite with suite definition configuration. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotdeviceadvisor.suite.definition.update(
                ctx, suite_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotdeviceadvisor.suite.definition.update suite_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotdeviceadvisor",
        operation="update_suite_definition",
        op_kwargs={
            "suiteDefinitionId": suite_definition_id,
            "suiteDefinitionConfiguration": suite_definition_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub, ctx, connector_types: List = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     Describes the connectors vended by Amazon AppFlow for specified connector types. If you don't specify a connector type, this operation describes all connectors vended by Amazon AppFlow. If there are more connectors than can be returned in one page, the response contains a nextToken object, which can be be passed in to the next call to the DescribeConnectors API operation to retrieve the next page.

    Args:
        connector_types(List, optional):  The type of connector, such as Salesforce, Amplitude, and so on. . Defaults to None.
        next_token(str, optional):  The pagination token for the next page of data. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appflow.connector.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appflow.connector.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appflow",
        operation="describe_connectors",
        op_kwargs={"connectorTypes": connector_types, "nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    certificate_authority_arn: str,
    s3_bucket_name: str,
    audit_report_response_format: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an audit report that lists every time that your CA private key is used. The report is saved in the Amazon S3 bucket that you specify on input. The IssueCertificate and RevokeCertificate actions use the private key.   Both PCA and the IAM principal must have permission to write to the S3 bucket that you specify. If the IAM principal making the call does not have permission to write to the bucket, then an exception is thrown. For more information, see Configure Access to ACM Private CA.  ACM Private CA assets that are stored in Amazon S3 can be protected with encryption. For more information, see Encrypting Your Audit Reports.

    Args:
        certificate_authority_arn(str): The Amazon Resource Name (ARN) of the CA to be audited. This is of the form:  arn:aws:acm-pca:region:account:certificate-authority/12345678-1234-1234-1234-123456789012 .
        s3_bucket_name(str): The name of the S3 bucket that will contain the audit report.
        audit_report_response_format(str): The format in which to create the report. This can be either JSON or CSV.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm_pca.certificate.authority.audit_report.create(
                ctx,
                certificate_authority_arn=value,
                s3_bucket_name=value,
                audit_report_response_format=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm_pca.certificate.authority.audit_report.create certificate_authority_arn=value, s3_bucket_name=value, audit_report_response_format=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm-pca",
        operation="create_certificate_authority_audit_report",
        op_kwargs={
            "CertificateAuthorityArn": certificate_authority_arn,
            "S3BucketName": s3_bucket_name,
            "AuditReportResponseFormat": audit_report_response_format,
        },
    )


async def describe(
    hub, ctx, certificate_authority_arn: str, audit_report_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Lists information about a specific audit report created by calling the CreateCertificateAuthorityAuditReport action. Audit information is created every time the certificate authority (CA) private key is used. The private key is used when you call the IssueCertificate action or the RevokeCertificate action.

    Args:
        certificate_authority_arn(str): The Amazon Resource Name (ARN) of the private CA. This must be of the form:  arn:aws:acm-pca:region:account:certificate-authority/12345678-1234-1234-1234-123456789012 . .
        audit_report_id(str): The report ID returned by calling the CreateCertificateAuthorityAuditReport action.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm_pca.certificate.authority.audit_report.describe(
                ctx, certificate_authority_arn=value, audit_report_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm_pca.certificate.authority.audit_report.describe certificate_authority_arn=value, audit_report_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm-pca",
        operation="describe_certificate_authority_audit_report",
        op_kwargs={
            "CertificateAuthorityArn": certificate_authority_arn,
            "AuditReportId": audit_report_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def export(hub, ctx, client_vpn_endpoint_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Downloads the contents of the Client VPN endpoint configuration file for the specified Client VPN endpoint. The Client VPN endpoint configuration file includes the Client VPN endpoint and certificate information clients need to establish a connection with the Client VPN endpoint.

    Args:
        client_vpn_endpoint_id(str): The ID of the Client VPN endpoint.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.client_vpn.client.configuration.export(
                ctx, client_vpn_endpoint_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.client_vpn.client.configuration.export client_vpn_endpoint_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="export_client_vpn_client_configuration",
        op_kwargs={"ClientVpnEndpointId": client_vpn_endpoint_id, "DryRun": dry_run},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    engine_type: str = None,
    host_instance_type: str = None,
    max_results: int = None,
    next_token: str = None,
    storage_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describe available broker instance options.

    Args:
        engine_type(str, optional): Filter response by engine type. Defaults to None.
        host_instance_type(str, optional): Filter response by host instance type. Defaults to None.
        max_results(int, optional): The maximum number of brokers that Amazon MQ can return per page (20 by default). This value must be an integer from 5 to 100. Defaults to None.
        next_token(str, optional): The token that specifies the next page of results Amazon MQ should return. To request the first page, leave nextToken empty. Defaults to None.
        storage_type(str, optional): Filter response by storage type. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mq.broker.instance_option.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mq.broker.instance_option.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mq",
        operation="describe_broker_instance_options",
        op_kwargs={
            "EngineType": engine_type,
            "HostInstanceType": host_instance_type,
            "MaxResults": max_results,
            "NextToken": next_token,
            "StorageType": storage_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(
    hub,
    ctx,
    cancel_reason: str = None,
    dry_run: bool = None,
    import_task_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Cancels an in-process import virtual machine or import snapshot task.

    Args:
        cancel_reason(str, optional): The reason for canceling the task. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        import_task_id(str, optional): The ID of the import image or import snapshot task to be canceled. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.import_.task.cancel(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.import_.task.cancel
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="cancel_import_task",
        op_kwargs={
            "CancelReason": cancel_reason,
            "DryRun": dry_run,
            "ImportTaskId": import_task_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, page_size: int = None, marker: str = None, ascending_order: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the role aliases registered in your account.

    Args:
        page_size(int, optional): The maximum number of results to return at one time. Defaults to None.
        marker(str, optional): A marker used to get the next set of results. Defaults to None.
        ascending_order(bool, optional): Return the list of role aliases in ascending alphabetical order. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.role_aliase.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.role_aliase.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_role_aliases",
        op_kwargs={
            "pageSize": page_size,
            "marker": marker,
            "ascendingOrder": ascending_order,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    aws_account_id: str,
    account_customization: Dict,
    namespace: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates Amazon QuickSight customizations the current Region;. Currently, you can add a custom default theme by using the CreateAccountCustomization or UpdateAccountCustomization API operation. To further customize QuickSight by removing QuickSight sample assets and videos for all new users, see Customizing QuickSight in the Amazon QuickSight User Guide.  You can create customizations for your Amazon Web Services account; or, if you specify a namespace, for a QuickSight namespace instead. Customizations that apply to a namespace always override customizations that apply to an Amazon Web Services account;. To find out which customizations apply, use the DescribeAccountCustomization API operation. Before you use the CreateAccountCustomization API operation to add a theme as the namespace default, make sure that you first share the theme with the namespace. If you don't share it with the namespace, the theme isn't visible to your users even if you make it the default theme. To check if the theme is shared, view the current permissions by using the  DescribeThemePermissions  API operation. To share the theme, grant permissions by using the  UpdateThemePermissions  API operation.

    Args:
        aws_account_id(str): The ID for the Amazon Web Services account; that you want to customize QuickSight for.
        namespace(str, optional): The QuickSight namespace that you want to add customizations to. Defaults to None.
        account_customization(Dict): The QuickSight customizations you're adding in the current Region;. You can add these to an Amazon Web Services account; and a QuickSight namespace.  For example, you can add a default theme by setting AccountCustomization to the midnight theme: "AccountCustomization": { "DefaultTheme": "arn:aws:quicksight::aws:theme/MIDNIGHT" }. Or, you can add a custom theme by specifying "AccountCustomization": { "DefaultTheme": "arn:aws:quicksight:us-west-2:111122223333:theme/bdb844d0-0fe9-4d9d-b520-0fe602d93639" }. .
        tags(List, optional): A list of the tags that you want to attach to this resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.account.customization.create(
                ctx, aws_account_id=value, account_customization=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.account.customization.create aws_account_id=value, account_customization=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="create_account_customization",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "Namespace": namespace,
            "AccountCustomization": account_customization,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, aws_account_id: str, namespace: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes all Amazon QuickSight customizations in this Region; for the specified Amazon Web Services account; and QuickSight namespace.

    Args:
        aws_account_id(str): The ID for the Amazon Web Services account; that you want to delete QuickSight customizations from in this Region;.
        namespace(str, optional): The QuickSight namespace that you're deleting the customizations from. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.account.customization.delete(
                ctx, aws_account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.account.customization.delete aws_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="delete_account_customization",
        op_kwargs={"AwsAccountId": aws_account_id, "Namespace": namespace},
    )


async def describe(
    hub, ctx, aws_account_id: str, namespace: str = None, resolved: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the customizations associated with the provided Amazon Web Services account; and Amazon QuickSight namespace in an Region;. The QuickSight console evaluates which customizations to apply by running this API operation with the Resolved flag included.  To determine what customizations display when you run this command, it can help to visualize the relationship of the entities involved.     Amazon Web Services account; - The Amazon Web Services account; exists at the top of the hierarchy. It has the potential to use all of the Regions; and AWS Services. When you subscribe to QuickSight, you choose one Region; to use as your home Region. That's where your free SPICE capacity is located. You can use QuickSight in any supported Region;.     Region; - In each Region; where you sign in to QuickSight at least once, QuickSight acts as a separate instance of the same service. If you have a user directory, it resides in us-east-1, which is the US East (N. Virginia). Generally speaking, these users have access to QuickSight in any Region;, unless they are constrained to a namespace.  To run the command in a different Region;, you change your Region settings. If you're using the AWS CLI, you can use one of the following options:   Use command line options.    Use named profiles.    Run aws configure to change your default Region;. Use Enter to key the same settings for your keys. For more information, see Configuring the AWS CLI.      Namespace - A QuickSight namespace is a partition that contains users and assets (data sources, datasets, dashboards, and so on). To access assets that are in a specific namespace, users and groups must also be part of the same namespace. People who share a namespace are completely isolated from users and assets in other namespaces, even if they are in the same Amazon Web Services account; and Region;.    Applied customizations - Within an Region;, a set of QuickSight customizations can apply to an Amazon Web Services account; or to a namespace. Settings that you apply to a namespace override settings that you apply to an Amazon Web Services account;. All settings are isolated to a single Region;. To apply them in other Regions;, run the CreateAccountCustomization command in each Region; where you want to apply the same customizations.

    Args:
        aws_account_id(str): The ID for the Amazon Web Services account; that you want to describe QuickSight customizations for.
        namespace(str, optional): The QuickSight namespace that you want to describe QuickSight customizations for. Defaults to None.
        resolved(bool, optional): The Resolved flag works with the other parameters to determine which view of QuickSight customizations is returned. You can add this flag to your command to use the same view that QuickSight uses to identify which customizations to apply to the console. Omit this flag, or set it to no-resolved, to reveal customizations that are configured at different levels. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.account.customization.describe(
                ctx, aws_account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.account.customization.describe aws_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="describe_account_customization",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "Namespace": namespace,
            "Resolved": resolved,
        },
    )


async def update(
    hub, ctx, aws_account_id: str, account_customization: Dict, namespace: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates Amazon QuickSight customizations the current Region;. Currently, the only customization you can use is a theme. You can use customizations for your Amazon Web Services account; or, if you specify a namespace, for a QuickSight namespace instead. Customizations that apply to a namespace override customizations that apply to an Amazon Web Services account;. To find out which customizations apply, use the DescribeAccountCustomization API operation.

    Args:
        aws_account_id(str): The ID for the Amazon Web Services account; that you want to update QuickSight customizations for.
        namespace(str, optional): The namespace that you want to update QuickSight customizations for. Defaults to None.
        account_customization(Dict): The QuickSight customizations you're updating in the current Region;. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.account.customization.update(
                ctx, aws_account_id=value, account_customization=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.account.customization.update aws_account_id=value, account_customization=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="update_account_customization",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "Namespace": namespace,
            "AccountCustomization": account_customization,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def generate(
    hub,
    ctx,
    aws_account_id: str,
    user_arn: str,
    experience_configuration: Dict,
    session_lifetime_in_minutes: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Generates an embed URL that you can use to embed an Amazon QuickSight experience in your website. This action can be used for any type of user registered in an Amazon QuickSight account. Before you use this action, make sure that you have configured the relevant Amazon QuickSight resource and permissions. The following rules apply to the generated URL:   It contains a temporary bearer token. It is valid for 5 minutes after it is generated. Once redeemed within this period, it cannot be re-used again.   The URL validity period should not be confused with the actual session lifetime that can be customized using the  SessionLifetimeInMinutes  parameter. The resulting user session is valid for 15 minutes (default) to 10 hours (maximum).   You are charged only when the URL is used or there is interaction with Amazon QuickSight.   For more information, see Embedded Analytics in the Amazon QuickSight User Guide. For more information about the high-level steps for embedding and for an interactive demo of the ways you can customize embedding, visit the Amazon QuickSight Developer Portal.

    Args:
        aws_account_id(str): The ID for the Amazon Web Services account that contains the dashboard that you're embedding.
        session_lifetime_in_minutes(int, optional): How many minutes the session is valid. The session lifetime must be in [15-600] minutes range. Defaults to None.
        user_arn(str): The Amazon Resource Name for the registered user.
        experience_configuration(Dict): The experience you are embedding. For registered users, you can embed Amazon QuickSight dashboards or the entire Amazon QuickSight console.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.embed_url_for_.registered_user.generate(
                ctx, aws_account_id=value, user_arn=value, experience_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.embed_url_for_.registered_user.generate aws_account_id=value, user_arn=value, experience_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="generate_embed_url_for_registered_user",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "SessionLifetimeInMinutes": session_lifetime_in_minutes,
            "UserArn": user_arn,
            "ExperienceConfiguration": experience_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def send(
    hub,
    ctx,
    session_token: str = None,
    start_session: Dict = None,
    start_transaction: Dict = None,
    end_session: Dict = None,
    commit_transaction: Dict = None,
    abort_transaction: Dict = None,
    execute_statement: Dict = None,
    fetch_page: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Sends a command to an Amazon QLDB ledger.  Instead of interacting directly with this API, we recommend using the QLDB driver or the QLDB shell to execute data transactions on a ledger.   If you are working with an AWS SDK, use the QLDB driver. The driver provides a high-level abstraction layer above this QLDB Session data plane and manages SendCommand API calls for you. For information and a list of supported programming languages, see Getting started with the driver in the Amazon QLDB Developer Guide.   If you are working with the AWS Command Line Interface (AWS CLI), use the QLDB shell. The shell is a command line interface that uses the QLDB driver to interact with a ledger. For information, see Accessing Amazon QLDB using the QLDB shell.

    Args:
        session_token(str, optional): Specifies the session token for the current command. A session token is constant throughout the life of the session. To obtain a session token, run the StartSession command. This SessionToken is required for every subsequent command that is issued during the current session. Defaults to None.
        start_session(Dict, optional): Command to start a new session. A session token is obtained as part of the response. Defaults to None.
        start_transaction(Dict, optional): Command to start a new transaction. Defaults to None.
        end_session(Dict, optional): Command to end the current session. Defaults to None.
        commit_transaction(Dict, optional): Command to commit the specified transaction. Defaults to None.
        abort_transaction(Dict, optional): Command to abort the current transaction. Defaults to None.
        execute_statement(Dict, optional): Command to execute a statement in the specified transaction. Defaults to None.
        fetch_page(Dict, optional): Command to fetch a page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.qldb_session_command.send(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.qldb_session_command.send
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="qldb-session",
        operation="send_command",
        op_kwargs={
            "SessionToken": session_token,
            "StartSession": start_session,
            "StartTransaction": start_transaction,
            "EndSession": end_session,
            "CommitTransaction": commit_transaction,
            "AbortTransaction": abort_transaction,
            "ExecuteStatement": execute_statement,
            "FetchPage": fetch_page,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub, ctx, environment_id: str = None, environment_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns AWS resources for this environment.

    Args:
        environment_id(str, optional): The ID of the environment to retrieve AWS resource usage data.  Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. . Defaults to None.
        environment_name(str, optional): The name of the environment to retrieve AWS resource usage data.  Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.environment.resource.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.environment.resource.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="describe_environment_resources",
        op_kwargs={
            "EnvironmentId": environment_id,
            "EnvironmentName": environment_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"import_": "import"}


async def delete(hub, ctx, certificate_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a certificate and its associated private key. If this action succeeds, the certificate no longer appears in the list that can be displayed by calling the ListCertificates action or be retrieved by calling the GetCertificate action. The certificate will not be available for use by Amazon Web Services services integrated with ACM.   You cannot delete an ACM certificate that is being used by another Amazon Web Services service. To delete a certificate that is in use, the certificate association must first be removed.

    Args:
        certificate_arn(str): String that contains the ARN of the ACM certificate to be deleted. This must be of the form:  arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012  For more information about ARNs, see Amazon Resource Names (ARNs).
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm.certificate.init.delete(ctx, certificate_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm.certificate.init.delete certificate_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm",
        operation="delete_certificate",
        op_kwargs={"CertificateArn": certificate_arn},
    )


async def describe(hub, ctx, certificate_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns detailed metadata about the specified ACM certificate.

    Args:
        certificate_arn(str): The Amazon Resource Name (ARN) of the ACM certificate. The ARN must have the following form:  arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012  For more information about ARNs, see Amazon Resource Names (ARNs).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm.certificate.init.describe(ctx, certificate_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm.certificate.init.describe certificate_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm",
        operation="describe_certificate",
        op_kwargs={"CertificateArn": certificate_arn},
    )


async def export(hub, ctx, certificate_arn: str, passphrase: bytes) -> Dict:
    r"""
    **Autogenerated function**

    Exports a private certificate issued by a private certificate authority (CA) for use anywhere. The exported file contains the certificate, the certificate chain, and the encrypted private 2048-bit RSA key associated with the public key that is embedded in the certificate. For security, you must assign a passphrase for the private key when exporting it.  For information about exporting and formatting a certificate using the ACM console or CLI, see Export a Private Certificate.

    Args:
        certificate_arn(str): An Amazon Resource Name (ARN) of the issued certificate. This must be of the form:  arn:aws:acm:region:account:certificate/12345678-1234-1234-1234-123456789012 .
        passphrase(bytes): Passphrase to associate with the encrypted exported private key. If you want to later decrypt the private key, you must have the passphrase. You can use the following OpenSSL command to decrypt a private key:   openssl rsa -in encrypted_key.pem -out decrypted_key.pem .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm.certificate.init.export(ctx, certificate_arn=value, passphrase=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm.certificate.init.export certificate_arn=value, passphrase=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm",
        operation="export_certificate",
        op_kwargs={"CertificateArn": certificate_arn, "Passphrase": passphrase},
    )


async def get(hub, ctx, certificate_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves an Amazon-issued certificate and its certificate chain. The chain consists of the certificate of the issuing CA and the intermediate certificates of any other subordinate CAs. All of the certificates are base64 encoded. You can use OpenSSL to decode the certificates and inspect individual fields.

    Args:
        certificate_arn(str): String that contains a certificate ARN in the following format:  arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012  For more information about ARNs, see Amazon Resource Names (ARNs).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm.certificate.init.get(ctx, certificate_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm.certificate.init.get certificate_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm",
        operation="get_certificate",
        op_kwargs={"CertificateArn": certificate_arn},
    )


async def import_(
    hub,
    ctx,
    certificate: bytes,
    private_key: bytes,
    certificate_arn: str = None,
    certificate_chain: bytes = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Imports a certificate into Amazon Web Services Certificate Manager (ACM) to use with services that are integrated with ACM. Note that integrated services allow only certificate types and keys they support to be associated with their resources. Further, their support differs depending on whether the certificate is imported into IAM or into ACM. For more information, see the documentation for each service. For more information about importing certificates into ACM, see Importing Certificates in the Amazon Web Services Certificate Manager User Guide.   ACM does not provide managed renewal for certificates that you import.  Note the following guidelines when importing third party certificates:   You must enter the private key that matches the certificate you are importing.   The private key must be unencrypted. You cannot import a private key that is protected by a password or a passphrase.   The private key must be no larger than 5 KB (5,120 bytes).   If the certificate you are importing is not self-signed, you must enter its certificate chain.   If a certificate chain is included, the issuer must be the subject of one of the certificates in the chain.   The certificate, private key, and certificate chain must be PEM-encoded.   The current time must be between the Not Before and Not After certificate fields.   The Issuer field must not be empty.   The OCSP authority URL, if present, must not exceed 1000 characters.   To import a new certificate, omit the CertificateArn argument. Include this argument only when you want to replace a previously imported certificate.   When you import a certificate by using the CLI, you must specify the certificate, the certificate chain, and the private key by their file names preceded by fileb://. For example, you can specify a certificate saved in the C:\temp folder as fileb://C:\temp\certificate_to_import.pem. If you are making an HTTP or HTTPS Query request, include these arguments as BLOBs.    When you import a certificate by using an SDK, you must specify the certificate, the certificate chain, and the private key files in the manner required by the programming language you're using.    The cryptographic algorithm of an imported certificate must match the algorithm of the signing CA. For example, if the signing CA key type is RSA, then the certificate key type must also be RSA.   This operation returns the Amazon Resource Name (ARN) of the imported certificate.

    Args:
        certificate_arn(str, optional): The Amazon Resource Name (ARN) of an imported certificate to replace. To import a new certificate, omit this field. . Defaults to None.
        certificate(bytes): The certificate to import.
        private_key(bytes): The private key that matches the public key in the certificate.
        certificate_chain(bytes, optional): The PEM encoded certificate chain. Defaults to None.
        tags(List, optional): One or more resource tags to associate with the imported certificate.  Note: You cannot apply tags when reimporting a certificate. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm.certificate.init.import(ctx, certificate=value, private_key=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm.certificate.init.import certificate=value, private_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm",
        operation="import_certificate",
        op_kwargs={
            "CertificateArn": certificate_arn,
            "Certificate": certificate,
            "PrivateKey": private_key,
            "CertificateChain": certificate_chain,
            "Tags": tags,
        },
    )


async def list_all(
    hub,
    ctx,
    certificate_statuses: List = None,
    includes: Dict = None,
    next_token: str = None,
    max_items: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of certificate ARNs and domain names. You can request that only certificates that match a specific status be listed. You can also filter by specific attributes of the certificate. Default filtering returns only RSA_2048 certificates. For more information, see Filters.

    Args:
        certificate_statuses(List, optional): Filter the certificate list by status value. Defaults to None.
        includes(Dict, optional): Filter the certificate list. For more information, see the Filters structure. Defaults to None.
        next_token(str, optional): Use this parameter only when paginating results and only in a subsequent request after you receive a response with truncated results. Set it to the value of NextToken from the response you just received. Defaults to None.
        max_items(int, optional): Use this parameter when paginating results to specify the maximum number of items to return in the response. If additional items exist beyond the number you specify, the NextToken element is sent in the response. Use this NextToken value in a subsequent request to retrieve additional items. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm.certificate.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm.certificate.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm",
        operation="list_certificates",
        op_kwargs={
            "CertificateStatuses": certificate_statuses,
            "Includes": includes,
            "NextToken": next_token,
            "MaxItems": max_items,
        },
    )


async def renew(hub, ctx, certificate_arn: str) -> None:
    r"""
    **Autogenerated function**

    Renews an eligible ACM certificate. At this time, only exported private certificates can be renewed with this operation. In order to renew your ACM PCA certificates with ACM, you must first grant the ACM service principal permission to do so. For more information, see Testing Managed Renewal in the ACM User Guide.

    Args:
        certificate_arn(str): String that contains the ARN of the ACM certificate to be renewed. This must be of the form:  arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012  For more information about ARNs, see Amazon Resource Names (ARNs).
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm.certificate.init.renew(ctx, certificate_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm.certificate.init.renew certificate_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm",
        operation="renew_certificate",
        op_kwargs={"CertificateArn": certificate_arn},
    )


async def request(
    hub,
    ctx,
    domain_name: str,
    validation_method: str = None,
    subject_alternative_names: List = None,
    idempotency_token: str = None,
    domain_validation_options: List = None,
    options: Dict = None,
    certificate_authority_arn: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Requests an ACM certificate for use with other Amazon Web Services services. To request an ACM certificate, you must specify a fully qualified domain name (FQDN) in the DomainName parameter. You can also specify additional FQDNs in the SubjectAlternativeNames parameter.  If you are requesting a private certificate, domain validation is not required. If you are requesting a public certificate, each domain name that you specify must be validated to verify that you own or control the domain. You can use DNS validation or email validation. We recommend that you use DNS validation. ACM issues public certificates after receiving approval from the domain owner.   ACM behavior differs from the https://tools.ietf.org/html/rfc6125#appendix-B.2RFC 6125 specification of the certificate validation process. first checks for a subject alternative name, and, if it finds one, ignores the common name (CN)

    Args:
        domain_name(str):  Fully qualified domain name (FQDN), such as www.example.com, that you want to secure with an ACM certificate. Use an asterisk (*) to create a wildcard certificate that protects several sites in the same domain. For example, *.example.com protects www.example.com, site.example.com, and images.example.com.   The first domain name you enter cannot exceed 64 octets, including periods. Each subsequent Subject Alternative Name (SAN), however, can be up to 253 octets in length. .
        validation_method(str, optional): The method you want to use if you are requesting a public certificate to validate that you own or control domain. You can validate with DNS or validate with email. We recommend that you use DNS validation. . Defaults to None.
        subject_alternative_names(List, optional): Additional FQDNs to be included in the Subject Alternative Name extension of the ACM certificate. For example, add the name www.example.net to a certificate for which the DomainName field is www.example.com if users can reach your site by using either name. The maximum number of domain names that you can add to an ACM certificate is 100. However, the initial quota is 10 domain names. If you need more than 10 names, you must request a quota increase. For more information, see Quotas.  The maximum length of a SAN DNS name is 253 octets. The name is made up of multiple labels separated by periods. No label can be longer than 63 octets. Consider the following examples:     (63 octets).(63 octets).(63 octets).(61 octets) is legal because the total length is 253 octets (63+1+63+1+63+1+61) and no label exceeds 63 octets.    (64 octets).(63 octets).(63 octets).(61 octets) is not legal because the total length exceeds 253 octets (64+1+63+1+63+1+61) and the first label exceeds 63 octets.    (63 octets).(63 octets).(63 octets).(62 octets) is not legal because the total length of the DNS name (63+1+63+1+63+1+62) exceeds 253 octets.  . Defaults to None.
        idempotency_token(str, optional): Customer chosen string that can be used to distinguish between calls to RequestCertificate. Idempotency tokens time out after one hour. Therefore, if you call RequestCertificate multiple times with the same idempotency token within one hour, ACM recognizes that you are requesting only one certificate and will issue only one. If you change the idempotency token for each call, ACM recognizes that you are requesting multiple certificates. Defaults to None.
        domain_validation_options(List, optional): The domain name that you want ACM to use to send you emails so that you can validate domain ownership. Defaults to None.
        options(Dict, optional): Currently, you can use this parameter to specify whether to add the certificate to a certificate transparency log. Certificate transparency makes it possible to detect SSL/TLS certificates that have been mistakenly or maliciously issued. Certificates that have not been logged typically produce an error message in a browser. For more information, see Opting Out of Certificate Transparency Logging. Defaults to None.
        certificate_authority_arn(str, optional): The Amazon Resource Name (ARN) of the private certificate authority (CA) that will be used to issue the certificate. If you do not provide an ARN and you are trying to request a private certificate, ACM will attempt to issue a public certificate. For more information about private CAs, see the Amazon Web Services Certificate Manager Private Certificate Authority (PCA) user guide. The ARN must have the following form:   arn:aws:acm-pca:region:account:certificate-authority/12345678-1234-1234-1234-123456789012 . Defaults to None.
        tags(List, optional): One or more resource tags to associate with the certificate. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm.certificate.init.request(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm.certificate.init.request domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm",
        operation="request_certificate",
        op_kwargs={
            "DomainName": domain_name,
            "ValidationMethod": validation_method,
            "SubjectAlternativeNames": subject_alternative_names,
            "IdempotencyToken": idempotency_token,
            "DomainValidationOptions": domain_validation_options,
            "Options": options,
            "CertificateAuthorityArn": certificate_authority_arn,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, resource_arn: str, policy: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new resource policy with the specified policy statements.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the bot or bot alias that the resource policy is attached to.
        policy(str): A resource policy to add to the resource. The policy is a JSON structure that contains one or more statements that define the policy. The policy must follow the IAM syntax. For more information about the contents of a JSON policy document, see  IAM JSON policy reference .  If the policy isn't valid, Amazon Lex returns a validation exception.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.resource.policy.init.create(
                ctx, resource_arn=value, policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.resource.policy.init.create resource_arn=value, policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="create_resource_policy",
        op_kwargs={"resourceArn": resource_arn, "policy": policy},
    )


async def delete(hub, ctx, resource_arn: str, expected_revision_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Removes an existing policy from a bot or bot alias. If the resource doesn't have a policy attached, Amazon Lex returns an exception.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the bot or bot alias that has the resource policy attached.
        expected_revision_id(str, optional): The identifier of the revision to edit. If this ID doesn't match the current revision number, Amazon Lex returns an exception If you don't specify a revision ID, Amazon Lex will delete the current policy. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.resource.policy.init.delete(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.resource.policy.init.delete resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="delete_resource_policy",
        op_kwargs={
            "resourceArn": resource_arn,
            "expectedRevisionId": expected_revision_id,
        },
    )


async def describe(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the resource policy and policy revision for a bot or bot alias.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the bot or bot alias that the resource policy is attached to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.resource.policy.init.describe(
                ctx, resource_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.resource.policy.init.describe resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="describe_resource_policy",
        op_kwargs={"resourceArn": resource_arn},
    )


async def update(
    hub, ctx, resource_arn: str, policy: str, expected_revision_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Replaces the existing resource policy for a bot or bot alias with a new one. If the policy doesn't exist, Amazon Lex returns an exception.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the bot or bot alias that the resource policy is attached to.
        policy(str): A resource policy to add to the resource. The policy is a JSON structure that contains one or more statements that define the policy. The policy must follow the IAM syntax. For more information about the contents of a JSON policy document, see  IAM JSON policy reference .  If the policy isn't valid, Amazon Lex returns a validation exception.
        expected_revision_id(str, optional): The identifier of the revision of the policy to update. If this revision ID doesn't match the current revision ID, Amazon Lex throws an exception. If you don't specify a revision, Amazon Lex overwrites the contents of the policy with the new values. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.resource.policy.init.update(
                ctx, resource_arn=value, policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.resource.policy.init.update resource_arn=value, policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="update_resource_policy",
        op_kwargs={
            "resourceArn": resource_arn,
            "policy": policy,
            "expectedRevisionId": expected_revision_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, thing_name: str, shadow_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the shadow for the specified thing. For more information, see DeleteThingShadow in the AWS IoT Developer Guide.

    Args:
        thing_name(str): The name of the thing.
        shadow_name(str, optional): The name of the shadow. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot_data.thing_shadow.delete(ctx, thing_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot_data.thing_shadow.delete thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot-data",
        operation="delete_thing_shadow",
        op_kwargs={"thingName": thing_name, "shadowName": shadow_name},
    )


async def get(hub, ctx, thing_name: str, shadow_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets the shadow for the specified thing. For more information, see GetThingShadow in the AWS IoT Developer Guide.

    Args:
        thing_name(str): The name of the thing.
        shadow_name(str, optional): The name of the shadow. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot_data.thing_shadow.get(ctx, thing_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot_data.thing_shadow.get thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot-data",
        operation="get_thing_shadow",
        op_kwargs={"thingName": thing_name, "shadowName": shadow_name},
    )


async def update(
    hub, ctx, thing_name: str, payload: bytes, shadow_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the shadow for the specified thing. For more information, see UpdateThingShadow in the AWS IoT Developer Guide.

    Args:
        thing_name(str): The name of the thing.
        shadow_name(str, optional): The name of the shadow. Defaults to None.
        payload(bytes): The state information, in JSON format.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot_data.thing_shadow.update(
                ctx, thing_name=value, payload=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot_data.thing_shadow.update thing_name=value, payload=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot-data",
        operation="update_thing_shadow",
        op_kwargs={
            "thingName": thing_name,
            "shadowName": shadow_name,
            "payload": payload,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub,
    ctx,
    snapshot_identifier_list: List,
    manual_snapshot_retention_period: int = None,
    force: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the settings for a set of cluster snapshots.

    Args:
        snapshot_identifier_list(List): A list of snapshot identifiers you want to modify.
        manual_snapshot_retention_period(int, optional): The number of days that a manual snapshot is retained. If you specify the value -1, the manual snapshot is retained indefinitely. The number must be either -1 or an integer between 1 and 3,653. If you decrease the manual snapshot retention period from its current value, existing manual snapshots that fall outside of the new retention period will return an error. If you want to suppress the errors and delete the snapshots, use the force option. . Defaults to None.
        force(bool, optional): A boolean value indicating whether to override an exception if the retention period has passed. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.modify_cluster_snapshot.batch(
                ctx, snapshot_identifier_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.modify_cluster_snapshot.batch snapshot_identifier_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="batch_modify_cluster_snapshots",
        op_kwargs={
            "SnapshotIdentifierList": snapshot_identifier_list,
            "ManualSnapshotRetentionPeriod": manual_snapshot_retention_period,
            "Force": force,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> None:
    r"""
    **Autogenerated function**

    Apply cost-allocation tags to a specified stack or layer in AWS OpsWorks Stacks. For more information about how tagging works, see Tags in the AWS OpsWorks User Guide.

    Args:
        resource_arn(str): The stack or layer's Amazon Resource Number (ARN).
        tags(Dict): A map that contains tag keys and tag values that are attached to a stack or layer.   The key cannot be empty.   The key can be a maximum of 127 characters, and can contain only Unicode letters, numbers, or separators, or the following special characters: + - = . _ : /    The value can be a maximum 255 characters, and contain only Unicode letters, numbers, or separators, or the following special characters: + - = . _ : /    Leading and trailing white spaces are trimmed from both the key and value.   A maximum of 40 tags is allowed for any resource.  .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Removes tags from a specified stack or layer.

    Args:
        resource_arn(str): The stack or layer's Amazon Resource Number (ARN).
        tag_keys(List): A list of the keys of tags to be removed from a stack or layer.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def delete(hub, ctx, application_name: str, environment_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the draft configuration associated with the running environment. Updating a running environment with any configuration changes creates a draft configuration set. You can get the draft configuration using DescribeConfigurationSettings while the update is in progress or if the update fails. The DeploymentStatus for the draft configuration indicates whether the deployment is in process or has failed. The draft configuration remains in existence until it is deleted with this action.

    Args:
        application_name(str): The name of the application the environment is associated with.
        environment_name(str): The name of the environment to delete the draft configuration from.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.environment.configuration.delete(
                ctx, application_name=value, environment_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.environment.configuration.delete application_name=value, environment_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="delete_environment_configuration",
        op_kwargs={
            "ApplicationName": application_name,
            "EnvironmentName": environment_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, catalog: str, entity_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the metadata and content of the entity.

    Args:
        catalog(str): Required. The catalog related to the request. Fixed value: AWSMarketplace .
        entity_id(str): Required. The unique ID of the entity to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.marketplace_catalog.entity.describe(
                ctx, catalog=value, entity_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.marketplace_catalog.entity.describe catalog=value, entity_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="marketplace-catalog",
        operation="describe_entity",
        op_kwargs={"Catalog": catalog, "EntityId": entity_id},
    )


async def list_all(
    hub,
    ctx,
    catalog: str,
    entity_type: str,
    filter_list: List = None,
    sort: Dict = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides the list of entities of a given type.

    Args:
        catalog(str): The catalog related to the request. Fixed value: AWSMarketplace .
        entity_type(str): The type of entities to retrieve.
        filter_list(List, optional): An array of filter objects. Each filter object contains two attributes, filterName and filterValues. Defaults to None.
        sort(Dict, optional): An object that contains two attributes, SortBy and SortOrder. Defaults to None.
        next_token(str, optional): The value of the next token, if it exists. Null if there are no more results. Defaults to None.
        max_results(int, optional): Specifies the upper limit of the elements on a single page. If a value isn't provided, the default value is 20. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.marketplace_catalog.entity.list_all(
                ctx, catalog=value, entity_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.marketplace_catalog.entity.list_all catalog=value, entity_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="marketplace-catalog",
        operation="list_entities",
        op_kwargs={
            "Catalog": catalog,
            "EntityType": entity_type,
            "FilterList": filter_list,
            "Sort": sort,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, time_range: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves (queries) aggregated usage data for an account.

    Args:
        time_range(str, optional): The inclusive time period to retrieve the data for. Valid values are: MONTH_TO_DATE, for the current calendar month to date; and, PAST_30_DAYS, for the preceding 30 days. If you don't specify a value for this parameter, Amazon Macie provides aggregated usage data for the preceding 30 days. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.usage.total.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.usage.total.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="get_usage_totals",
        op_kwargs={"timeRange": time_range},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, name: str, account: str) -> Dict:
    r"""
    **Autogenerated function**

    Called by an SaaS partner to create a partner event source. This operation is not used by AWS customers. Each partner event source can be used by one AWS account to create a matching partner event bus in that AWS account. A SaaS partner must create one partner event source for each AWS account that wants to receive those event types.  A partner event source creates events based on resources within the SaaS partner's service or application. An AWS account that creates a partner event bus that matches the partner event source can use that event bus to receive events from the partner, and then process them using AWS Events rules and targets. Partner event source names follow this format:   partner_name/event_namespace/event_name    partner_name is determined during partner registration and identifies the partner to AWS customers. event_namespace is determined by the partner and is a way for the partner to categorize their events. event_name is determined by the partner, and should uniquely identify an event-generating resource within the partner system. The combination of event_namespace and event_name should help AWS customers decide whether to create an event bus to receive these events.

    Args:
        name(str): The name of the partner event source. This name must be unique and must be in the format  partner_name/event_namespace/event_name . The AWS account that wants to use this partner event source must create a partner event bus with a name that matches the name of the partner event source.
        account(str): The AWS account ID that is permitted to create a matching partner event bus for this partner event source.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.partner_event.source.init.create(
                ctx, name=value, account=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.partner_event.source.init.create name=value, account=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="create_partner_event_source",
        op_kwargs={"Name": name, "Account": account},
    )


async def delete(hub, ctx, name: str, account: str) -> None:
    r"""
    **Autogenerated function**

    This operation is used by SaaS partners to delete a partner event source. This operation is not used by AWS customers. When you delete an event source, the status of the corresponding partner event bus in the AWS customer account becomes DELETED.

    Args:
        name(str): The name of the event source to delete.
        account(str): The AWS account ID of the AWS customer that the event source was created for.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.partner_event.source.init.delete(
                ctx, name=value, account=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.partner_event.source.init.delete name=value, account=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="delete_partner_event_source",
        op_kwargs={"Name": name, "Account": account},
    )


async def describe(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    An SaaS partner can use this operation to list details about a partner event source that they have created. AWS customers do not use this operation. Instead, AWS customers can use DescribeEventSource to see details about a partner event source that is shared with them.

    Args:
        name(str): The name of the event source to display.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.partner_event.source.init.describe(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.partner_event.source.init.describe name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="describe_partner_event_source",
        op_kwargs={"Name": name},
    )


async def list_all(
    hub, ctx, name_prefix: str, next_token: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    An SaaS partner can use this operation to list all the partner event source names that they have created. This operation is not used by AWS customers.

    Args:
        name_prefix(str): If you specify this, the results are limited to only those partner event sources that start with the string you specify.
        next_token(str, optional): The token returned by a previous call to this operation. Specifying this retrieves the next set of results. Defaults to None.
        limit(int, optional): pecifying this limits the number of results returned by this operation. The operation also returns a NextToken which you can use in a subsequent operation to retrieve the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.partner_event.source.init.list_all(ctx, name_prefix=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.partner_event.source.init.list_all name_prefix=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="list_partner_event_sources",
        op_kwargs={"NamePrefix": name_prefix, "NextToken": next_token, "Limit": limit},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def detect(
    hub,
    ctx,
    project_version_arn: str,
    image: Dict,
    max_results: int = None,
    min_confidence: float = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Detects custom labels in a supplied image by using an Amazon Rekognition Custom Labels model.  You specify which version of a model version to use by using the ProjectVersionArn input parameter.  You pass the input image as base64-encoded image bytes or as a reference to an image in an Amazon S3 bucket. If you use the AWS CLI to call Amazon Rekognition operations, passing image bytes is not supported. The image must be either a PNG or JPEG formatted file.   For each object that the model version detects on an image, the API returns a (CustomLabel) object in an array (CustomLabels). Each CustomLabel object provides the label name (Name), the level of confidence that the image contains the object (Confidence), and object location information, if it exists, for the label on the image (Geometry).  During training model calculates a threshold value that determines if a prediction for a label is true. By default, DetectCustomLabels doesn't return labels whose confidence value is below the model's calculated threshold value. To filter labels that are returned, specify a value for MinConfidence that is higher than the model's calculated threshold. You can get the model's calculated threshold from the model's training results shown in the Amazon Rekognition Custom Labels console. To get all labels, regardless of confidence, specify a MinConfidence value of 0.  You can also add the MaxResults parameter to limit the number of labels returned.  This is a stateless API operation. That is, the operation does not persist any data. This operation requires permissions to perform the rekognition:DetectCustomLabels action.

    Args:
        project_version_arn(str): The ARN of the model version that you want to use.
        image(Dict): Provides the input image either as bytes or an S3 object. You pass image bytes to an Amazon Rekognition API operation by using the Bytes property. For example, you would use the Bytes property to pass an image loaded from a local file system. Image bytes passed by using the Bytes property must be base64-encoded. Your code may not need to encode image bytes if you are using an AWS SDK to call Amazon Rekognition API operations.  For more information, see Analyzing an Image Loaded from a Local File System in the Amazon Rekognition Developer Guide.  You pass images stored in an S3 bucket to an Amazon Rekognition API operation by using the S3Object property. Images stored in an S3 bucket do not need to be base64-encoded. The region for the S3 bucket containing the S3 object must match the region you use for Amazon Rekognition operations. If you use the AWS CLI to call Amazon Rekognition operations, passing image bytes using the Bytes property is not supported. You must first upload the image to an Amazon S3 bucket and then call the operation using the S3Object property. For Amazon Rekognition to process an S3 object, the user must have permission to access the S3 object. For more information, see Resource Based Policies in the Amazon Rekognition Developer Guide. .
        max_results(int, optional): Maximum number of results you want the service to return in the response. The service returns the specified number of highest confidence labels ranked from highest confidence to lowest. Defaults to None.
        min_confidence(float, optional): Specifies the minimum confidence level for the labels to return. Amazon Rekognition doesn't return any labels with a confidence lower than this specified value. If you specify a value of 0, all labels are return, regardless of the default thresholds that the model version applies. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.custom_label.detect(
                ctx, project_version_arn=value, image=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.custom_label.detect project_version_arn=value, image=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="detect_custom_labels",
        op_kwargs={
            "ProjectVersionArn": project_version_arn,
            "Image": image,
            "MaxResults": max_results,
            "MinConfidence": min_confidence,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, resource_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Returns the current configuration for one or more requested resources. The operation also returns a list of resources that are not processed in the current request. If there are no unprocessed resources, the operation returns an empty unprocessedResourceKeys list.     The API does not return results for deleted resources.    The API does not return any tags for the requested resources. This information is filtered out of the supplementaryConfiguration section of the API response.

    Args:
        resource_keys(List): A list of resource keys to be processed with the current request. Each element in the list consists of the resource type and resource ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.get.resource_config.batch(ctx, resource_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.get.resource_config.batch resource_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="batch_get_resource_config",
        op_kwargs={"resourceKeys": resource_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def connect(
    hub,
    ctx,
    name: str,
    password: str,
    size: str,
    connect_settings: Dict,
    short_name: str = None,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an AD Connector to connect to an on-premises directory. Before you call ConnectDirectory, ensure that all of the required permissions have been explicitly granted through a policy. For details about what permissions are required to run the ConnectDirectory operation, see AWS Directory Service API Permissions: Actions, Resources, and Conditions Reference.

    Args:
        name(str): The fully qualified name of the on-premises directory, such as corp.example.com.
        short_name(str, optional): The NetBIOS name of the on-premises directory, such as CORP. Defaults to None.
        password(str): The password for the on-premises user account.
        description(str, optional): A description for the directory. Defaults to None.
        size(str): The size of the directory.
        connect_settings(Dict): A DirectoryConnectSettings object that contains additional information for the operation.
        tags(List, optional): The tags to be assigned to AD Connector. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.directory.init.connect(
                ctx, name=value, password=value, size=value, connect_settings=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.directory.init.connect name=value, password=value, size=value, connect_settings=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="connect_directory",
        op_kwargs={
            "Name": name,
            "ShortName": short_name,
            "Password": password,
            "Description": description,
            "Size": size,
            "ConnectSettings": connect_settings,
            "Tags": tags,
        },
    )


async def create(
    hub,
    ctx,
    name: str,
    password: str,
    size: str,
    short_name: str = None,
    description: str = None,
    vpc_settings: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Simple AD directory. For more information, see Simple Active Directory in the AWS Directory Service Admin Guide. Before you call CreateDirectory, ensure that all of the required permissions have been explicitly granted through a policy. For details about what permissions are required to run the CreateDirectory operation, see AWS Directory Service API Permissions: Actions, Resources, and Conditions Reference.

    Args:
        name(str): The fully qualified name for the directory, such as corp.example.com.
        short_name(str, optional): The NetBIOS name of the directory, such as CORP. Defaults to None.
        password(str): The password for the directory administrator. The directory creation process creates a directory administrator account with the user name Administrator and this password. If you need to change the password for the administrator account, you can use the ResetUserPassword API call. The regex pattern for this string is made up of the following conditions:   Length (?=^.{8,64}$) – Must be between 8 and 64 characters   AND any 3 of the following password complexity rules required by Active Directory:   Numbers and upper case and lowercase (?=.*\d)(?=.*[A-Z])(?=.*[a-z])   Numbers and special characters and lower case (?=.*\d)(?=.*[^A-Za-z0-9\s])(?=.*[a-z])   Special characters and upper case and lower case (?=.*[^A-Za-z0-9\s])(?=.*[A-Z])(?=.*[a-z])   Numbers and upper case and special characters (?=.*\d)(?=.*[A-Z])(?=.*[^A-Za-z0-9\s])   For additional information about how Active Directory passwords are enforced, see Password must meet complexity requirements on the Microsoft website.
        description(str, optional): A description for the directory. Defaults to None.
        size(str): The size of the directory.
        vpc_settings(Dict, optional): A DirectoryVpcSettings object that contains additional information for the operation. Defaults to None.
        tags(List, optional): The tags to be assigned to the Simple AD directory. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.directory.init.create(
                ctx, name=value, password=value, size=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.directory.init.create name=value, password=value, size=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="create_directory",
        op_kwargs={
            "Name": name,
            "ShortName": short_name,
            "Password": password,
            "Description": description,
            "Size": size,
            "VpcSettings": vpc_settings,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, directory_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an AWS Directory Service directory. Before you call DeleteDirectory, ensure that all of the required permissions have been explicitly granted through a policy. For details about what permissions are required to run the DeleteDirectory operation, see AWS Directory Service API Permissions: Actions, Resources, and Conditions Reference.

    Args:
        directory_id(str): The identifier of the directory to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.directory.init.delete(ctx, directory_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.directory.init.delete directory_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="delete_directory",
        op_kwargs={"DirectoryId": directory_id},
    )


async def describe_all(
    hub, ctx, directory_ids: List = None, next_token: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Obtains information about the directories that belong to this account. You can retrieve information about specific directories by passing the directory identifiers in the DirectoryIds parameter. Otherwise, all directories that belong to the current account are returned. This operation supports pagination with the use of the NextToken request and response parameters. If more results are available, the DescribeDirectoriesResult.NextToken member contains a token that you pass in the next call to DescribeDirectories to retrieve the next set of items. You can also specify a maximum number of return results with the Limit parameter.

    Args:
        directory_ids(List, optional): A list of identifiers of the directories for which to obtain the information. If this member is null, all directories that belong to the current account are returned. An empty list results in an InvalidParameterException being thrown. Defaults to None.
        next_token(str, optional): The DescribeDirectoriesResult.NextToken value from a previous call to DescribeDirectories. Pass null if this is the first call. Defaults to None.
        limit(int, optional): The maximum number of items to return. If this value is zero, the maximum number of items is specified by the limitations of the operation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.directory.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.directory.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="describe_directories",
        op_kwargs={
            "DirectoryIds": directory_ids,
            "NextToken": next_token,
            "Limit": limit,
        },
    )


async def share(
    hub,
    ctx,
    directory_id: str,
    share_target: Dict,
    share_method: str,
    share_notes: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Shares a specified directory (DirectoryId) in your AWS account (directory owner) with another AWS account (directory consumer). With this operation you can use your directory from any AWS account and from any Amazon VPC within an AWS Region. When you share your AWS Managed Microsoft AD directory, AWS Directory Service creates a shared directory in the directory consumer account. This shared directory contains the metadata to provide access to the directory within the directory owner account. The shared directory is visible in all VPCs in the directory consumer account. The ShareMethod parameter determines whether the specified directory can be shared between AWS accounts inside the same AWS organization (ORGANIZATIONS). It also determines whether you can share the directory with any other AWS account either inside or outside of the organization (HANDSHAKE). The ShareNotes parameter is only used when HANDSHAKE is called, which sends a directory sharing request to the directory consumer.

    Args:
        directory_id(str): Identifier of the AWS Managed Microsoft AD directory that you want to share with other AWS accounts.
        share_notes(str, optional): A directory share request that is sent by the directory owner to the directory consumer. The request includes a typed message to help the directory consumer administrator determine whether to approve or reject the share invitation. Defaults to None.
        share_target(Dict): Identifier for the directory consumer account with whom the directory is to be shared.
        share_method(str): The method used when sharing a directory to determine whether the directory should be shared within your AWS organization (ORGANIZATIONS) or with any AWS account by sending a directory sharing request (HANDSHAKE).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.directory.init.share(
                ctx, directory_id=value, share_target=value, share_method=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.directory.init.share directory_id=value, share_target=value, share_method=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="share_directory",
        op_kwargs={
            "DirectoryId": directory_id,
            "ShareNotes": share_notes,
            "ShareTarget": share_target,
            "ShareMethod": share_method,
        },
    )


async def unshare(hub, ctx, directory_id: str, unshare_target: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Stops the directory sharing between the directory owner and consumer accounts.

    Args:
        directory_id(str): The identifier of the AWS Managed Microsoft AD directory that you want to stop sharing.
        unshare_target(Dict): Identifier for the directory consumer account with whom the directory has to be unshared.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.directory.init.unshare(
                ctx, directory_id=value, unshare_target=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.directory.init.unshare directory_id=value, unshare_target=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="unshare_directory",
        op_kwargs={"DirectoryId": directory_id, "UnshareTarget": unshare_target},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


__func_alias__ = {"set_": "set"}


async def set_(
    hub,
    ctx,
    instance_id: str,
    health_status: str,
    should_respect_grace_period: bool = None,
) -> None:
    r"""
    **Autogenerated function**

    Sets the health status of the specified instance. For more information, see Health checks for Auto Scaling instances in the Amazon EC2 Auto Scaling User Guide.

    Args:
        instance_id(str): The ID of the instance.
        health_status(str): The health status of the instance. Set to Healthy to have the instance remain in service. Set to Unhealthy to have the instance be out of service. Amazon EC2 Auto Scaling terminates and replaces the unhealthy instance.
        should_respect_grace_period(bool, optional): If the Auto Scaling group of the specified instance has a HealthCheckGracePeriod specified for the group, by default, this call respects the grace period. Set this to False, to have the call not respect the grace period associated with the group. For more information about the health check grace period, see CreateAutoScalingGroup in the Amazon EC2 Auto Scaling API Reference. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.instance.health.set(
                ctx, instance_id=value, health_status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.instance.health.set instance_id=value, health_status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="set_instance_health",
        op_kwargs={
            "InstanceId": instance_id,
            "HealthStatus": health_status,
            "ShouldRespectGracePeriod": should_respect_grace_period,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def complete(
    hub,
    ctx,
    snapshot_id: str,
    changed_blocks_count: int,
    checksum: str = None,
    checksum_algorithm: str = None,
    checksum_aggregation_method: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Seals and completes the snapshot after all of the required blocks of data have been written to it. Completing the snapshot changes the status to completed. You cannot write new blocks to a snapshot after it has been completed.

    Args:
        snapshot_id(str): The ID of the snapshot.
        changed_blocks_count(int): The number of blocks that were written to the snapshot.
        checksum(str, optional): An aggregated Base-64 SHA256 checksum based on the checksums of each written block. To generate the aggregated checksum using the linear aggregation method, arrange the checksums for each written block in ascending order of their block index, concatenate them to form a single string, and then generate the checksum on the entire string using the SHA256 algorithm. Defaults to None.
        checksum_algorithm(str, optional): The algorithm used to generate the checksum. Currently, the only supported algorithm is SHA256. Defaults to None.
        checksum_aggregation_method(str, optional): The aggregation method used to generate the checksum. Currently, the only supported aggregation method is LINEAR. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ebs.snapshot.init.complete(
                ctx, snapshot_id=value, changed_blocks_count=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ebs.snapshot.init.complete snapshot_id=value, changed_blocks_count=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ebs",
        operation="complete_snapshot",
        op_kwargs={
            "SnapshotId": snapshot_id,
            "ChangedBlocksCount": changed_blocks_count,
            "Checksum": checksum,
            "ChecksumAlgorithm": checksum_algorithm,
            "ChecksumAggregationMethod": checksum_aggregation_method,
        },
    )


async def start(
    hub,
    ctx,
    volume_size: int,
    parent_snapshot_id: str = None,
    tags: List = None,
    description: str = None,
    client_token: str = None,
    encrypted: bool = None,
    kms_key_arn: str = None,
    timeout: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Amazon EBS snapshot. The new snapshot enters the pending state after the request completes.  After creating the snapshot, use  PutSnapshotBlock to write blocks of data to the snapshot.

    Args:
        volume_size(int): The size of the volume, in GiB. The maximum size is 16384 GiB (16 TiB).
        parent_snapshot_id(str, optional): The ID of the parent snapshot. If there is no parent snapshot, or if you are creating the first snapshot for an on-premises volume, omit this parameter. If your account is enabled for encryption by default, you cannot use an unencrypted snapshot as a parent snapshot. You must first create an encrypted copy of the parent snapshot using CopySnapshot. Defaults to None.
        tags(List, optional): The tags to apply to the snapshot. Defaults to None.
        description(str, optional): A description for the snapshot. Defaults to None.
        client_token(str, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully. The subsequent retries with the same client token return the result from the original successful request and they have no additional effect. If you do not specify a client token, one is automatically generated by the AWS SDK. For more information, see  Idempotency for StartSnapshot API in the Amazon Elastic Compute Cloud User Guide. Defaults to None.
        encrypted(bool, optional): Indicates whether to encrypt the snapshot. To create an encrypted snapshot, specify true. To create an unencrypted snapshot, omit this parameter. If you specify a value for ParentSnapshotId, omit this parameter. If you specify true, the snapshot is encrypted using the CMK specified using the KmsKeyArn parameter. If no value is specified for KmsKeyArn, the default CMK for your account is used. If no default CMK has been specified for your account, the AWS managed CMK is used. To set a default CMK for your account, use  ModifyEbsDefaultKmsKeyId. If your account is enabled for encryption by default, you cannot set this parameter to false. In this case, you can omit this parameter. For more information, see  Using encryption in the Amazon Elastic Compute Cloud User Guide. Defaults to None.
        kms_key_arn(str, optional): The Amazon Resource Name (ARN) of the AWS Key Management Service (AWS KMS) customer master key (CMK) to be used to encrypt the snapshot. If you do not specify a CMK, the default AWS managed CMK is used. If you specify a ParentSnapshotId, omit this parameter; the snapshot will be encrypted using the same CMK that was used to encrypt the parent snapshot. If Encrypted is set to true, you must specify a CMK ARN. . Defaults to None.
        timeout(int, optional): The amount of time (in minutes) after which the snapshot is automatically cancelled if:   No blocks are written to the snapshot.   The snapshot is not completed after writing the last block of data.   If no value is specified, the timeout defaults to 60 minutes. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ebs.snapshot.init.start(ctx, volume_size=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ebs.snapshot.init.start volume_size=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ebs",
        operation="start_snapshot",
        op_kwargs={
            "VolumeSize": volume_size,
            "ParentSnapshotId": parent_snapshot_id,
            "Tags": tags,
            "Description": description,
            "ClientToken": client_token,
            "Encrypted": encrypted,
            "KmsKeyArn": kms_key_arn,
            "Timeout": timeout,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub, ctx, engine_name: str, max_records: int = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the possible endpoint settings available when you create an endpoint for a specific database engine.

    Args:
        engine_name(str): The databse engine used for your source or target endpoint.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved. Defaults to None.
        marker(str, optional): An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.endpoint.setting.describe_all(ctx, engine_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.endpoint.setting.describe_all engine_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="describe_endpoint_settings",
        op_kwargs={
            "EngineName": engine_name,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def add(
    hub, ctx, directory_id: str, region_name: str, vpc_settings: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Adds two domain controllers in the specified Region for the specified directory.

    Args:
        directory_id(str): The identifier of the directory to which you want to add Region replication.
        region_name(str): The name of the Region where you want to add domain controllers for replication. For example, us-east-1.
        vpc_settings(Dict): Contains VPC information for the CreateDirectory or CreateMicrosoftAD operation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.region.add(
                ctx, directory_id=value, region_name=value, vpc_settings=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.region.add directory_id=value, region_name=value, vpc_settings=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="add_region",
        op_kwargs={
            "DirectoryId": directory_id,
            "RegionName": region_name,
            "VPCSettings": vpc_settings,
        },
    )


async def describe_all(
    hub, ctx, directory_id: str, region_name: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Provides information about the Regions that are configured for multi-Region replication.

    Args:
        directory_id(str): The identifier of the directory.
        region_name(str, optional): The name of the Region. For example, us-east-1. Defaults to None.
        next_token(str, optional): The DescribeRegionsResult.NextToken value from a previous call to DescribeRegions. Pass null if this is the first call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.region.describe_all(ctx, directory_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.region.describe_all directory_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="describe_regions",
        op_kwargs={
            "DirectoryId": directory_id,
            "RegionName": region_name,
            "NextToken": next_token,
        },
    )


async def remove(hub, ctx, directory_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops all replication and removes the domain controllers from the specified Region. You cannot remove the primary Region with this operation. Instead, use the DeleteDirectory API.

    Args:
        directory_id(str): The identifier of the directory for which you want to remove Region replication.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.region.remove(ctx, directory_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.region.remove directory_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="remove_region",
        op_kwargs={"DirectoryId": directory_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    reserved_instances_modification_ids: List = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the modifications made to your Reserved Instances. If no parameter is specified, information about all your Reserved Instances modification requests is returned. If a modification ID is specified, only information about the specific modification is returned. For more information, see Modifying Reserved Instances in the Amazon EC2 User Guide.

    Args:
        filters(List, optional): One or more filters.    client-token - The idempotency token for the modification request.    create-date - The time when the modification request was created.    effective-date - The time when the modification becomes effective.    modification-result.reserved-instances-id - The ID for the Reserved Instances created as part of the modification request. This ID is only available when the status of the modification is fulfilled.    modification-result.target-configuration.availability-zone - The Availability Zone for the new Reserved Instances.    modification-result.target-configuration.instance-count  - The number of new Reserved Instances.    modification-result.target-configuration.instance-type - The instance type of the new Reserved Instances.    modification-result.target-configuration.platform - The network platform of the new Reserved Instances (EC2-Classic | EC2-VPC).    reserved-instances-id - The ID of the Reserved Instances modified.    reserved-instances-modification-id - The ID of the modification request.    status - The status of the Reserved Instances modification request (processing | fulfilled | failed).    status-message - The reason for the status.    update-date - The time when the modification request was last updated.  . Defaults to None.
        reserved_instances_modification_ids(List, optional): IDs for the submitted modification request. Defaults to None.
        next_token(str, optional): The token to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.reserved_instance.modification.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.reserved_instance.modification.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_reserved_instances_modifications",
        op_kwargs={
            "Filters": filters,
            "ReservedInstancesModificationIds": reserved_instances_modification_ids,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub,
    ctx,
    global_network_id: str,
    transit_gateway_connect_peer_arn: str,
    device_id: str,
    link_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a transit gateway Connect peer with a device, and optionally, with a link. If you specify a link, it must be associated with the specified device.  You can only associate transit gateway Connect peers that have been created on a transit gateway that's registered in your global network. You cannot associate a transit gateway Connect peer with more than one device and link.

    Args:
        global_network_id(str): The ID of the global network.
        transit_gateway_connect_peer_arn(str): The Amazon Resource Name (ARN) of the Connect peer.
        device_id(str): The ID of the device.
        link_id(str, optional): The ID of the link. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.transit_gateway.connect_peer.init.associate(
                ctx,
                global_network_id=value,
                transit_gateway_connect_peer_arn=value,
                device_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.transit_gateway.connect_peer.init.associate global_network_id=value, transit_gateway_connect_peer_arn=value, device_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="associate_transit_gateway_connect_peer",
        op_kwargs={
            "GlobalNetworkId": global_network_id,
            "TransitGatewayConnectPeerArn": transit_gateway_connect_peer_arn,
            "DeviceId": device_id,
            "LinkId": link_id,
        },
    )


async def disassociate(
    hub, ctx, global_network_id: str, transit_gateway_connect_peer_arn: str
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a transit gateway Connect peer from a device and link.

    Args:
        global_network_id(str): The ID of the global network.
        transit_gateway_connect_peer_arn(str): The Amazon Resource Name (ARN) of the transit gateway Connect peer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.transit_gateway.connect_peer.init.disassociate(
                ctx, global_network_id=value, transit_gateway_connect_peer_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.transit_gateway.connect_peer.init.disassociate global_network_id=value, transit_gateway_connect_peer_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="disassociate_transit_gateway_connect_peer",
        op_kwargs={
            "GlobalNetworkId": global_network_id,
            "TransitGatewayConnectPeerArn": transit_gateway_connect_peer_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def stop(hub, ctx, entity_recognizer_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops an entity recognizer training job while in progress. If the training job state is TRAINING, the job is marked for termination and put into the STOP_REQUESTED state. If the training job completes before it can be stopped, it is put into the TRAINED; otherwise the training job is stopped and putted into the STOPPED state and the service sends back an HTTP 200 response with an empty HTTP body.

    Args:
        entity_recognizer_arn(str): The Amazon Resource Name (ARN) that identifies the entity recognizer currently being trained.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.training.entity_recognizer.stop(
                ctx, entity_recognizer_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.training.entity_recognizer.stop entity_recognizer_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="stop_training_entity_recognizer",
        op_kwargs={"EntityRecognizerArn": entity_recognizer_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    backup_plan_id: str,
    backup_selection: Dict,
    creator_request_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a JSON document that specifies a set of resources to assign to a backup plan. Resources can be included by specifying patterns for a ListOfTags and selected Resources.  For example, consider the following patterns:    Resources: "arn:aws:ec2:region:account-id:volume/volume-id"     ConditionKey:"department"   ConditionValue:"finance"   ConditionType:"StringEquals"     ConditionKey:"importance"   ConditionValue:"critical"   ConditionType:"StringEquals"    Using these patterns would back up all Amazon Elastic Block Store (Amazon EBS) volumes that are tagged as "department=finance", "importance=critical", in addition to an EBS volume with the specified volume ID. Resources and conditions are additive in that all resources that match the pattern are selected. This shouldn't be confused with a logical AND, where all conditions must match. The matching patterns are logically put together using the OR operator. In other words, all patterns that match are selected for backup.

    Args:
        backup_plan_id(str): Uniquely identifies the backup plan to be associated with the selection of resources.
        backup_selection(Dict): Specifies the body of a request to assign a set of resources to a backup plan.
        creator_request_id(str, optional): A unique string that identifies the request and allows failed requests to be retried without the risk of running the operation twice. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.selection.create(
                ctx, backup_plan_id=value, backup_selection=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.selection.create backup_plan_id=value, backup_selection=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="create_backup_selection",
        op_kwargs={
            "BackupPlanId": backup_plan_id,
            "BackupSelection": backup_selection,
            "CreatorRequestId": creator_request_id,
        },
    )


async def delete(hub, ctx, backup_plan_id: str, selection_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the resource selection associated with a backup plan that is specified by the SelectionId.

    Args:
        backup_plan_id(str): Uniquely identifies a backup plan.
        selection_id(str): Uniquely identifies the body of a request to assign a set of resources to a backup plan.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.selection.delete(
                ctx, backup_plan_id=value, selection_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.selection.delete backup_plan_id=value, selection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="delete_backup_selection",
        op_kwargs={"BackupPlanId": backup_plan_id, "SelectionId": selection_id},
    )


async def get(hub, ctx, backup_plan_id: str, selection_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns selection metadata and a document in JSON format that specifies a list of resources that are associated with a backup plan.

    Args:
        backup_plan_id(str): Uniquely identifies a backup plan.
        selection_id(str): Uniquely identifies the body of a request to assign a set of resources to a backup plan.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.selection.get(
                ctx, backup_plan_id=value, selection_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.selection.get backup_plan_id=value, selection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="get_backup_selection",
        op_kwargs={"BackupPlanId": backup_plan_id, "SelectionId": selection_id},
    )


async def list_all(
    hub, ctx, backup_plan_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array containing metadata of the resources associated with the target backup plan.

    Args:
        backup_plan_id(str): Uniquely identifies a backup plan.
        next_token(str, optional): The next item following a partial list of returned items. For example, if a request is made to return maxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token. Defaults to None.
        max_results(int, optional): The maximum number of items to be returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.selection.list_all(ctx, backup_plan_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.selection.list_all backup_plan_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="list_backup_selections",
        op_kwargs={
            "BackupPlanId": backup_plan_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, cluster_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels a cluster job. You can only cancel a cluster job while it's in the AwaitingQuorum status. You'll have at least an hour after creating a cluster job to cancel it.

    Args:
        cluster_id(str): The 39-character ID for the cluster that you want to cancel, for example CID123e4567-e89b-12d3-a456-426655440000.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.cluster.init.cancel(ctx, cluster_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.cluster.init.cancel cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="cancel_cluster",
        op_kwargs={"ClusterId": cluster_id},
    )


async def create(
    hub,
    ctx,
    job_type: str,
    resources: Dict,
    address_id: str,
    role_arn: str,
    snowball_type: str,
    shipping_option: str,
    on_device_service_configuration: Dict = None,
    description: str = None,
    kms_key_arn: str = None,
    notification: Dict = None,
    forwarding_address_id: str = None,
    tax_documents: Dict = None,
    remote_management: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an empty cluster. Each cluster supports five nodes. You use the CreateJob action separately to create the jobs for each of these nodes. The cluster does not ship until these five node jobs have been created.

    Args:
        job_type(str): The type of job for this cluster. Currently, the only job type supported for clusters is LOCAL_USE. For more information, see "https://docs.aws.amazon.com/snowball/latest/snowcone-guide/snow-device-types.html" (Snow Family Devices and Capacity) in the Snowcone User Guide or "https://docs.aws.amazon.com/snowball/latest/developer-guide/snow-device-types.html" (Snow Family Devices and Capacity) in the Snowcone User Guide.
        resources(Dict): The resources associated with the cluster job. These resources include Amazon S3 buckets and optional AWS Lambda functions written in the Python language. .
        on_device_service_configuration(Dict, optional): Specifies the service or services on the Snow Family device that your transferred data will be exported from or imported into. AWS Snow Family supports Amazon S3 and NFS (Network File System). Defaults to None.
        description(str, optional): An optional description of this specific cluster, for example Environmental Data Cluster-01. Defaults to None.
        address_id(str): The ID for the address that you want the cluster shipped to.
        kms_key_arn(str, optional): The KmsKeyARN value that you want to associate with this cluster. KmsKeyARN values are created by using the CreateKey API action in AWS Key Management Service (AWS KMS). . Defaults to None.
        role_arn(str): The RoleARN that you want to associate with this cluster. RoleArn values are created by using the CreateRole API action in AWS Identity and Access Management (IAM).
        snowball_type(str): The type of AWS Snow Family device to use for this cluster.   For cluster jobs, AWS Snow Family currently supports only the EDGE device type.  For more information, see "https://docs.aws.amazon.com/snowball/latest/snowcone-guide/snow-device-types.html" (Snow Family Devices and Capacity) in the Snowcone User Guide or "https://docs.aws.amazon.com/snowball/latest/developer-guide/snow-device-types.html" (Snow Family Devices and Capacity) in the Snowcone User Guide.
        shipping_option(str): The shipping speed for each node in this cluster. This speed doesn't dictate how soon you'll get each Snowball Edge device, rather it represents how quickly each device moves to its destination while in transit. Regional shipping speeds are as follows:    In Australia, you have access to express shipping. Typically, Snow devices shipped express are delivered in about a day.   In the European Union (EU), you have access to express shipping. Typically, Snow devices shipped express are delivered in about a day. In addition, most countries in the EU have access to standard shipping, which typically takes less than a week, one way.   In India, Snow devices are delivered in one to seven days.   In the United States of America (US), you have access to one-day shipping and two-day shipping.     In Australia, you have access to express shipping. Typically, devices shipped express are delivered in about a day.   In the European Union (EU), you have access to express shipping. Typically, Snow devices shipped express are delivered in about a day. In addition, most countries in the EU have access to standard shipping, which typically takes less than a week, one way.   In India, Snow devices are delivered in one to seven days.   In the US, you have access to one-day shipping and two-day shipping.  .
        notification(Dict, optional): The Amazon Simple Notification Service (Amazon SNS) notification settings for this cluster. Defaults to None.
        forwarding_address_id(str, optional): The forwarding address ID for a cluster. This field is not supported in most regions. Defaults to None.
        tax_documents(Dict, optional): The tax documents required in your AWS Region. Defaults to None.
        remote_management(str, optional): Allows you to securely operate and manage Snow devices in a cluster remotely from outside of your internal network. When set to INSTALLED_AUTOSTART, remote management will automatically be available when the device arrives at your location. Otherwise, you need to use the Snowball Client to manage the device. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.cluster.init.create(
                ctx,
                job_type=value,
                resources=value,
                address_id=value,
                role_arn=value,
                snowball_type=value,
                shipping_option=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.cluster.init.create job_type=value, resources=value, address_id=value, role_arn=value, snowball_type=value, shipping_option=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="create_cluster",
        op_kwargs={
            "JobType": job_type,
            "Resources": resources,
            "OnDeviceServiceConfiguration": on_device_service_configuration,
            "Description": description,
            "AddressId": address_id,
            "KmsKeyARN": kms_key_arn,
            "RoleARN": role_arn,
            "SnowballType": snowball_type,
            "ShippingOption": shipping_option,
            "Notification": notification,
            "ForwardingAddressId": forwarding_address_id,
            "TaxDocuments": tax_documents,
            "RemoteManagement": remote_management,
        },
    )


async def describe(hub, ctx, cluster_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a specific cluster including shipping information, cluster status, and other important metadata.

    Args:
        cluster_id(str): The automatically generated ID for a cluster.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.cluster.init.describe(ctx, cluster_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.cluster.init.describe cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="describe_cluster",
        op_kwargs={"ClusterId": cluster_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of ClusterListEntry objects of the specified length. Each ClusterListEntry object contains a cluster's state, a cluster's ID, and other important status information.

    Args:
        max_results(int, optional): The number of ClusterListEntry objects to return. Defaults to None.
        next_token(str, optional): HTTP requests are stateless. To identify what object comes "next" in the list of ClusterListEntry objects, you have the option of specifying NextToken as the starting point for your returned list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.cluster.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.cluster.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="list_clusters",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    cluster_id: str,
    role_arn: str = None,
    description: str = None,
    resources: Dict = None,
    on_device_service_configuration: Dict = None,
    address_id: str = None,
    shipping_option: str = None,
    notification: Dict = None,
    forwarding_address_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    While a cluster's ClusterState value is in the AwaitingQuorum state, you can update some of the information associated with a cluster. Once the cluster changes to a different job state, usually 60 minutes after the cluster being created, this action is no longer available.

    Args:
        cluster_id(str): The cluster ID of the cluster that you want to update, for example CID123e4567-e89b-12d3-a456-426655440000.
        role_arn(str, optional): The new role Amazon Resource Name (ARN) that you want to associate with this cluster. To create a role ARN, use the CreateRole API action in AWS Identity and Access Management (IAM). Defaults to None.
        description(str, optional): The updated description of this cluster. Defaults to None.
        resources(Dict, optional): The updated arrays of JobResource objects that can include updated S3Resource objects or LambdaResource objects. Defaults to None.
        on_device_service_configuration(Dict, optional): Specifies the service or services on the Snow Family device that your transferred data will be exported from or imported into. AWS Snow Family supports Amazon S3 and NFS (Network File System). Defaults to None.
        address_id(str, optional): The ID of the updated Address object. Defaults to None.
        shipping_option(str, optional): The updated shipping option value of this cluster's ShippingDetails object. Defaults to None.
        notification(Dict, optional): The new or updated Notification object. Defaults to None.
        forwarding_address_id(str, optional): The updated ID for the forwarding address for a cluster. This field is not supported in most regions. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.cluster.init.update(ctx, cluster_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.cluster.init.update cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="update_cluster",
        op_kwargs={
            "ClusterId": cluster_id,
            "RoleARN": role_arn,
            "Description": description,
            "Resources": resources,
            "OnDeviceServiceConfiguration": on_device_service_configuration,
            "AddressId": address_id,
            "ShippingOption": shipping_option,
            "Notification": notification,
            "ForwardingAddressId": forwarding_address_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, fleet_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides basic information for the specified fleet, excluding identity provider, networking, and device configuration details.

    Args:
        fleet_arn(str): The Amazon Resource Name (ARN) of the fleet.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.fleet.metadata.describe(ctx, fleet_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.fleet.metadata.describe fleet_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="describe_fleet_metadata",
        op_kwargs={"FleetArn": fleet_arn},
    )


async def update(
    hub,
    ctx,
    fleet_arn: str,
    display_name: str = None,
    optimize_for_end_user_location: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates fleet metadata, such as DisplayName.

    Args:
        fleet_arn(str): The ARN of the fleet.
        display_name(str, optional): The fleet name to display. The existing DisplayName is unset if null is passed. Defaults to None.
        optimize_for_end_user_location(bool, optional): The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.fleet.metadata.update(ctx, fleet_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.fleet.metadata.update fleet_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="update_fleet_metadata",
        op_kwargs={
            "FleetArn": fleet_arn,
            "DisplayName": display_name,
            "OptimizeForEndUserLocation": optimize_for_end_user_location,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_arn: str, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    List all tags on an Amazon DynamoDB resource. You can call ListTagsOfResource up to 10 times per second, per account. For an overview on tagging DynamoDB resources, see Tagging for DynamoDB in the Amazon DynamoDB Developer Guide.

    Args:
        resource_arn(str): The Amazon DynamoDB resource with tags to be listed. This value is an Amazon Resource Name (ARN).
        next_token(str, optional): An optional string that, if supplied, must be copied from the output of a previous call to ListTagOfResource. When provided in this manner, this API fetches the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.tags_of_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.tags_of_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="list_tags_of_resource",
        op_kwargs={"ResourceArn": resource_arn, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, project_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a paginated list of assets associated with an IoT SiteWise Monitor project.

    Args:
        project_id(str): The ID of the project.
        next_token(str, optional): The token to be used for the next set of paginated results. Defaults to None.
        max_results(int, optional): The maximum number of results to return for each paginated request. Default: 50. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.project.asset.list_all(ctx, project_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.project.asset.list_all project_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="list_project_assets",
        op_kwargs={
            "projectId": project_id,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub, ctx, export_ids: List = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     DescribeExportConfigurations is deprecated. Use DescribeImportTasks, instead.

    Args:
        export_ids(List, optional): A list of continuous export IDs to search for. Defaults to None.
        max_results(int, optional): A number between 1 and 100 specifying the maximum number of continuous export descriptions returned. Defaults to None.
        next_token(str, optional): The token from the previous call to describe-export-tasks. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.discovery.export.configuration.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.discovery.export.configuration.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="discovery",
        operation="describe_export_configurations",
        op_kwargs={
            "exportIds": export_ids,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, user_pool_id: str, custom_attributes: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds additional user attributes to the user pool schema.

    Args:
        user_pool_id(str): The user pool ID for the user pool where you want to add custom attributes.
        custom_attributes(List): An array of custom attributes, such as Mutable and Name.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.custom_attribute.add(
                ctx, user_pool_id=value, custom_attributes=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.custom_attribute.add user_pool_id=value, custom_attributes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="add_custom_attributes",
        op_kwargs={"UserPoolId": user_pool_id, "CustomAttributes": custom_attributes},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def update_multiple(hub, ctx, cluster: str, settings: List) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the settings to use for a cluster.

    Args:
        cluster(str): The name of the cluster to modify the settings for.
        settings(List): The setting to use by default for a cluster. This parameter is used to enable CloudWatch Container Insights for a cluster. If this value is specified, it will override the containerInsights value set with PutAccountSetting or PutAccountSettingDefault.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.cluster.setting.update_multiple(
                ctx, cluster=value, settings=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.cluster.setting.update_multiple cluster=value, settings=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="update_cluster_settings",
        op_kwargs={"cluster": cluster, "settings": settings},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def update(
    hub, ctx, detector_id: str, finding_ids: List, feedback: str, comments: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Marks the specified GuardDuty findings as useful or not useful.

    Args:
        detector_id(str): The ID of the detector associated with the findings to update feedback for.
        finding_ids(List): The IDs of the findings that you want to mark as useful or not useful.
        feedback(str): The feedback for the finding.
        comments(str, optional): Additional feedback about the GuardDuty findings. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.finding.feedback.update(
                ctx, detector_id=value, finding_ids=value, feedback=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.finding.feedback.update detector_id=value, finding_ids=value, feedback=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="update_findings_feedback",
        op_kwargs={
            "DetectorId": detector_id,
            "FindingIds": finding_ids,
            "Feedback": feedback,
            "Comments": comments,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, index_id: str, documents: List, role_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Adds one or more documents to an index. The BatchPutDocument operation enables you to ingest inline documents or a set of documents stored in an Amazon S3 bucket. Use this operation to ingest your text and unstructured text into an index, add custom attributes to the documents, and to attach an access control list to the documents added to the index. The documents are indexed asynchronously. You can see the progress of the batch using Amazon Web Services CloudWatch. Any error messages related to processing the batch are sent to your Amazon Web Services CloudWatch log.

    Args:
        index_id(str): The identifier of the index to add the documents to. You need to create the index first using the CreateIndex operation.
        role_arn(str, optional): The Amazon Resource Name (ARN) of a role that is allowed to run the BatchPutDocument operation. For more information, see IAM Roles for Amazon Kendra. Defaults to None.
        documents(List): One or more documents to add to the index. Documents can include custom attributes. For example, 'DataSourceId' and 'DataSourceSyncJobId' are custom attributes that provide information on the synchronization of documents running on a data source. Note, 'DataSourceSyncJobId' could be an optional custom attribute as Amazon Kendra will use the ID of a running sync job. Documents have the following file size limits.   5 MB total size for inline documents   50 MB total size for files from an S3 bucket   5 MB extracted text for any file   For more information about file size and transaction per second quotas, see Quotas.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.put_document.batch(ctx, index_id=value, documents=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.put_document.batch index_id=value, documents=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="batch_put_document",
        op_kwargs={"IndexId": index_id, "RoleArn": role_arn, "Documents": documents},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def deregister(hub, ctx, load_balancer_name: str, instances: List) -> Dict:
    r"""
    **Autogenerated function**

    Deregisters the specified instances from the specified load balancer. After the instance is deregistered, it no longer receives traffic from the load balancer. You can use DescribeLoadBalancers to verify that the instance is deregistered from the load balancer. For more information, see Register or De-Register EC2 Instances in the Classic Load Balancers Guide.

    Args:
        load_balancer_name(str): The name of the load balancer.
        instances(List): The IDs of the instances.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.instance.from_load_balancer.deregister(
                ctx, load_balancer_name=value, instances=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.instance.from_load_balancer.deregister load_balancer_name=value, instances=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="deregister_instances_from_load_balancer",
        op_kwargs={"LoadBalancerName": load_balancer_name, "Instances": instances},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    fleet_id: str,
    dry_run: bool = None,
    max_results: int = None,
    next_token: str = None,
    filters: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the running instances for the specified EC2 Fleet. For more information, see Monitoring your EC2 Fleet in the Amazon EC2 User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Specify a value between 1 and 1000. The default value is 1000. To retrieve the remaining results, make another call with the returned NextToken value. Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.
        fleet_id(str): The ID of the EC2 Fleet.
        filters(List, optional): The filters.    instance-type - The instance type.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.fleet.instance.describe_all(ctx, fleet_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.fleet.instance.describe_all fleet_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_fleet_instances",
        op_kwargs={
            "DryRun": dry_run,
            "MaxResults": max_results,
            "NextToken": next_token,
            "FleetId": fleet_id,
            "Filters": filters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    configuration_aggregator_name: str,
    filters: Dict = None,
    group_by_key: str = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the count of compliant and noncompliant conformance packs across all AWS Accounts and AWS Regions in an aggregator. You can filter based on AWS Account ID or AWS Region.  The results can return an empty result page, but if you have a nextToken, the results are displayed on the next page.

    Args:
        configuration_aggregator_name(str): The name of the configuration aggregator.
        filters(Dict, optional): Filters the results based on the AggregateConformancePackComplianceSummaryFilters object. Defaults to None.
        group_by_key(str, optional): Groups the result based on AWS Account ID or AWS Region. Defaults to None.
        limit(int, optional): The maximum number of results returned on each page. The default is maximum. If you specify 0, AWS Config uses the default. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.aggregate.conformance_pack_compliance_summary.get(
                ctx, configuration_aggregator_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.aggregate.conformance_pack_compliance_summary.get configuration_aggregator_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="get_aggregate_conformance_pack_compliance_summary",
        op_kwargs={
            "ConfigurationAggregatorName": configuration_aggregator_name,
            "Filters": filters,
            "GroupByKey": group_by_key,
            "Limit": limit,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    thing_name: str,
    thing_type_name: str = None,
    attribute_payload: Dict = None,
    billing_group_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a thing record in the registry. If this call is made multiple times using the same thing name and configuration, the call will succeed. If this call is made with the same thing name but different configuration a ResourceAlreadyExistsException is thrown.  This is a control plane operation. See Authorization for information about authorizing control plane actions.

    Args:
        thing_name(str): The name of the thing to create. You can't change a thing's name after you create it. To change a thing's name, you must create a new thing, give it the new name, and then delete the old thing.
        thing_type_name(str, optional): The name of the thing type associated with the new thing. Defaults to None.
        attribute_payload(Dict, optional): The attribute payload, which consists of up to three name/value pairs in a JSON document. For example:  {\"attributes\":{\"string1\":\"string2\"}} . Defaults to None.
        billing_group_name(str, optional): The name of the billing group the thing will be added to. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.init.create(ctx, thing_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.init.create thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_thing",
        op_kwargs={
            "thingName": thing_name,
            "thingTypeName": thing_type_name,
            "attributePayload": attribute_payload,
            "billingGroupName": billing_group_name,
        },
    )


async def delete(hub, ctx, thing_name: str, expected_version: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified thing. Returns successfully with no error if the deletion is successful or you specify a thing that doesn't exist.

    Args:
        thing_name(str): The name of the thing to delete.
        expected_version(int, optional): The expected version of the thing record in the registry. If the version of the record in the registry does not match the expected version specified in the request, the DeleteThing request is rejected with a VersionConflictException. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.init.delete(ctx, thing_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.init.delete thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_thing",
        op_kwargs={"thingName": thing_name, "expectedVersion": expected_version},
    )


async def describe(hub, ctx, thing_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the specified thing.

    Args:
        thing_name(str): The name of the thing.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.init.describe(ctx, thing_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.init.describe thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_thing",
        op_kwargs={"thingName": thing_name},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    attribute_name: str = None,
    attribute_value: str = None,
    thing_type_name: str = None,
    use_prefix_attribute_value: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists your things. Use the attributeName and attributeValue parameters to filter your things. For example, calling ListThings with attributeName=Color and attributeValue=Red retrieves all things in the registry that contain an attribute Color with the value Red.   You will not be charged for calling this API if an Access denied error is returned. You will also not be charged if no attributes or pagination token was provided in request and no pagination token and no results were returned.

    Args:
        next_token(str, optional): To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in this operation. Defaults to None.
        attribute_name(str, optional): The attribute name used to search for things. Defaults to None.
        attribute_value(str, optional): The attribute value used to search for things. Defaults to None.
        thing_type_name(str, optional): The name of the thing type used to search for things. Defaults to None.
        use_prefix_attribute_value(bool, optional): When true, the action returns the thing resources with attribute values that start with the attributeValue provided. When false, or not present, the action returns only the thing resources with attribute values that match the entire attributeValue provided. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_things",
        op_kwargs={
            "nextToken": next_token,
            "maxResults": max_results,
            "attributeName": attribute_name,
            "attributeValue": attribute_value,
            "thingTypeName": thing_type_name,
            "usePrefixAttributeValue": use_prefix_attribute_value,
        },
    )


async def register(hub, ctx, template_body: str, parameters: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Provisions a thing in the device registry. RegisterThing calls other AWS IoT control plane APIs. These calls might exceed your account level  AWS IoT Throttling Limits and cause throttle errors. Please contact AWS Customer Support to raise your throttling limits if necessary.

    Args:
        template_body(str): The provisioning template. See Provisioning Devices That Have Device Certificates for more information.
        parameters(Dict, optional): The parameters for provisioning a thing. See Provisioning Templates for more information. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.init.register(ctx, template_body=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.init.register template_body=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="register_thing",
        op_kwargs={"templateBody": template_body, "parameters": parameters},
    )


async def update(
    hub,
    ctx,
    thing_name: str,
    thing_type_name: str = None,
    attribute_payload: Dict = None,
    expected_version: int = None,
    remove_thing_type: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the data for a thing.

    Args:
        thing_name(str): The name of the thing to update. You can't change a thing's name. To change a thing's name, you must create a new thing, give it the new name, and then delete the old thing.
        thing_type_name(str, optional): The name of the thing type. Defaults to None.
        attribute_payload(Dict, optional): A list of thing attributes, a JSON string containing name-value pairs. For example:  {\"attributes\":{\"name1\":\"value2\"}}  This data is used to add new attributes or update existing attributes. Defaults to None.
        expected_version(int, optional): The expected version of the thing record in the registry. If the version of the record in the registry does not match the expected version specified in the request, the UpdateThing request is rejected with a VersionConflictException. Defaults to None.
        remove_thing_type(bool, optional): Remove a thing type association. If true, the association is removed. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.init.update(ctx, thing_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.init.update thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_thing",
        op_kwargs={
            "thingName": thing_name,
            "thingTypeName": thing_type_name,
            "attributePayload": attribute_payload,
            "expectedVersion": expected_version,
            "removeThingType": remove_thing_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def update(
    hub, ctx, workspace_id: str, alias: str = None, client_token: str = None
) -> None:
    r"""
    **Autogenerated function**

    Updates an AMP workspace alias.

    Args:
        alias(str, optional): The new alias of the workspace. Defaults to None.
        client_token(str, optional): Optional, unique, case-sensitive, user-provided identifier to ensure the idempotency of the request. Defaults to None.
        workspace_id(str): The ID of the workspace being updated.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amp_workspace.alias.update(ctx, workspace_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amp_workspace.alias.update workspace_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amp",
        operation="update_workspace_alias",
        op_kwargs={
            "alias": alias,
            "clientToken": client_token,
            "workspaceId": workspace_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    application: str,
    environment: str,
    configuration: str,
    client_id: str,
    client_configuration_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Receive information about a configuration.  AWS AppConfig uses the value of the ClientConfigurationVersion parameter to identify the configuration version on your clients. If you don’t send ClientConfigurationVersion with each call to GetConfiguration, your clients receive the current configuration. You are charged each time your clients receive a configuration. To avoid excess charges, we recommend that you include the ClientConfigurationVersion value with every call to GetConfiguration. This value must be saved on your client. Subsequent calls to GetConfiguration must pass this value by using the ClientConfigurationVersion parameter.

    Args:
        application(str): The application to get. Specify either the application name or the application ID.
        environment(str): The environment to get. Specify either the environment name or the environment ID.
        configuration(str): The configuration to get. Specify either the configuration name or the configuration ID.
        client_id(str): A unique ID to identify the client for the configuration. This ID enables AppConfig to deploy the configuration in intervals, as defined in the deployment strategy.
        client_configuration_version(str, optional): The configuration version returned in the most recent GetConfiguration response.  AWS AppConfig uses the value of the ClientConfigurationVersion parameter to identify the configuration version on your clients. If you don’t send ClientConfigurationVersion with each call to GetConfiguration, your clients receive the current configuration. You are charged each time your clients receive a configuration. To avoid excess charges, we recommend that you include the ClientConfigurationVersion value with every call to GetConfiguration. This value must be saved on your client. Subsequent calls to GetConfiguration must pass this value by using the ClientConfigurationVersion parameter.   For more information about working with configurations, see Retrieving the Configuration in the AWS AppConfig User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.configuration.init.get(
                ctx, application=value, environment=value, configuration=value, client_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.configuration.init.get application=value, environment=value, configuration=value, client_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="get_configuration",
        op_kwargs={
            "Application": application,
            "Environment": environment,
            "Configuration": configuration,
            "ClientId": client_id,
            "ClientConfigurationVersion": client_configuration_version,
        },
    )


async def validate(
    hub,
    ctx,
    application_id: str,
    configuration_profile_id: str,
    configuration_version: str,
) -> None:
    r"""
    **Autogenerated function**

    Uses the validators in a configuration profile to validate a configuration.

    Args:
        application_id(str): The application ID.
        configuration_profile_id(str): The configuration profile ID.
        configuration_version(str): The version of the configuration to validate.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.configuration.init.validate(
                ctx,
                application_id=value,
                configuration_profile_id=value,
                configuration_version=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.configuration.init.validate application_id=value, configuration_profile_id=value, configuration_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="validate_configuration",
        op_kwargs={
            "ApplicationId": application_id,
            "ConfigurationProfileId": configuration_profile_id,
            "ConfigurationVersion": configuration_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, configuration_recorder_names: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the current status of the specified configuration recorder. If a configuration recorder is not specified, this action returns the status of all configuration recorders associated with the account.  Currently, you can specify only one configuration recorder per region in your account.

    Args:
        configuration_recorder_names(List, optional): The name(s) of the configuration recorder. If the name is not specified, the action returns the current status of all the configuration recorders associated with the account. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.configuration.recorder.status.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.configuration.recorder.status.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="describe_configuration_recorder_status",
        op_kwargs={"ConfigurationRecorderNames": configuration_recorder_names},
    )
